@@ -1,13 +1,13 @@
 package Pinto::Common;
 
-# ABSTRACT: Common modules for the pinto-* utilities
+# ABSTRACT: Common libraries for the L<Pinto> suite
 
 use strict;
 use warnings;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.045'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 #------------------------------------------------------------------------------
 1;
@@ -22,17 +22,17 @@ placeholders metacpan
 
 =head1 NAME
 
-Pinto::Common - Common modules for the pinto-* utilities
+Pinto::Common - Common libraries for the L<Pinto> suite
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 DESCRIPTION
 
 This distribution exists to provide modules that are used across
-L<pinto-admin>, L<pinto-server>, and L<pinto-remote>.  There are no
-user-serviceable parts in this distribution.
+L<pinto> and L<pintod>.  There are no user-serviceable parts in
+this distribution.
 
 =head1 SUPPORT
 
